summaryrefslogtreecommitdiffstats
path: root/lib/plugin.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:56:54 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:56:54 -0600
commit28879aa783655c1bb2b65e7761f8fe2a7cf8f7b2 (patch)
treef78e2df40f61288477bbd160d7c795918ad298d5 /lib/plugin.h
parent8ebd99fc2d3e2429a1030d60ce693b74b8832a40 (diff)
downloadkpilot-28879aa783655c1bb2b65e7761f8fe2a7cf8f7b2.tar.gz
kpilot-28879aa783655c1bb2b65e7761f8fe2a7cf8f7b2.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'lib/plugin.h')
-rw-r--r--lib/plugin.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/plugin.h b/lib/plugin.h
index 33cdee4..57761b2 100644
--- a/lib/plugin.h
+++ b/lib/plugin.h
@@ -43,7 +43,7 @@
class TQTabWidget;
-class KAboutData;
+class TDEAboutData;
class KLibrary;
class PilotDatabase;
@@ -137,11 +137,11 @@ public:
* "About".
*
* @param w The tab widget to which the about page is added.
* @param data The KAboutData that is used.
*
*/
static void addAboutPage(TQTabWidget *w,
- KAboutData *data=0L);
+ TDEAboutData *data=0L);
/**
* This creates the actual about widget. Again, public & static so
@@ -153,9 +153,9 @@ public:
* anywhere. Copied from KAboutDialog, mostly.
*
* @param parent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/
- static TQWidget *aboutPage(TQWidget *parent, KAboutData *data=0L);
+ static TQWidget *aboutPage(TQWidget *parent, TDEAboutData *data=0L);
protected:
/**
@@ -433,7 +433,7 @@ namespace PluginUtility
*
*
* <pre>
-* static KAboutData *about() { return fAbout; } ;
+* static TDEAboutData *about() { return fAbout; } ;
* </pre>
*
*
@@ -454,8 +454,8 @@ namespace PluginUtility
* by about() above.
*
* <pre>
-* KInstance *fInstance;
-* static KAboutData *fAbout;
+* TDEInstance *fInstance;
+* static TDEAboutData *fAbout;
* } ;
* </pre>
*
@@ -137,11 +137,11 @@ public:
*
* @param w The tab widget to which the about page is added.
- * @param data The KAboutData that is used.
+ * @param data The TDEAboutData that is used.
*
*/
@@ -153,9 +153,9 @@ public:
*
* @param parent The widget that holds the about widget.
- * @param data The KAboutData that is used to populate the widget.
+ * @param data The TDEAboutData that is used to populate the widget.
*/